//+------------------------------------------------------------------+
//|                                                 IMM_Position.mq4 |
//+------------------------------------------------------------------+
#property  copyright "Rondo"
#property  link      "http://fx-dollaryen.seesaa.net/"

//---- indicator settings
#property  indicator_separate_window
#property  indicator_buffers 5

#property  indicator_color1  CLR_NONE
#property  indicator_color2  Green
#property  indicator_color3  OliveDrab
#property  indicator_color4  Orange
#property  indicator_color5  Red

#property  indicator_width2  2
#property  indicator_width3  2
#property  indicator_width4  2
#property  indicator_width5  2

#property indicator_level1 0
#property indicator_levelcolor DimGray
#property indicator_levelstyle STYLE_SOLID


//---- indicator parameters
extern string FileName = "IMM_JPY.csv";
extern bool mirror = false;

//---- indicator buffers
double IMMBuffer[];
double LongUP[], LongDOWN[], ShortUP[], ShortDOWN[];

datetime time1;
   
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- drawing settings
   SetIndexStyle(0, DRAW_LINE);
   SetIndexStyle(1, DRAW_HISTOGRAM);
   SetIndexStyle(2, DRAW_HISTOGRAM);
   SetIndexStyle(3, DRAW_HISTOGRAM);
   SetIndexStyle(4, DRAW_HISTOGRAM);
   
//---- indicator buffers mapping
   SetIndexBuffer(0, IMMBuffer);
   SetIndexBuffer(1, LongUP);
   SetIndexBuffer(2, LongDOWN);
   SetIndexBuffer(3, ShortUP);
   SetIndexBuffer(4, ShortDOWN);
               
//---- name for DataWindow and indicator subwindow label
   IndicatorShortName("IMM Position ("+FileName+")");
   
   SetIndexLabel(0, "IMM Long-Short position");
   SetIndexLabel(1, NULL);
   SetIndexLabel(2, NULL);
   SetIndexLabel(3, NULL);
   SetIndexLabel(4, NULL);
   
//---- initialization done
   return(0);
  }
//+------------------------------------------------------------------+
//| Moving Averages Convergence/Divergence                           |
//+------------------------------------------------------------------+
int start()
  {
  
   if(time1 != Time[0]) time1 = Time[0];
   else return(0);
   
   int handle1 = FileOpen(FileName, FILE_CSV|FILE_READ, ",");
   
   if(handle1>0){

      for(int i=0; i<Bars; i++){
      
         if(FileIsEnding(handle1)) break;
      
         string strDate = FileReadString(handle1);            
                  
         // 2013/5/29 => 2013.5.29
         while(true){
         
            if(StringFind(strDate, "/")>0){
               
               int position = StringFind(strDate, "/");
               string frontDate = StringSubstr(strDate, 0, position);
               string backDate = StringSubstr(strDate, position+StringLen("/"));
               
               strDate = frontDate + "." + backDate;
            }
            else break;
         
         }

         if(StringFind(strDate, ".")<0) break;

         int t = iBarShift(NULL, 0, StrToTime(strDate), true);
         
         if(t>=0){
            double LongPosition = FileReadNumber(handle1);
            double ShortPosition = FileReadNumber(handle1);
         
            double difference = LongPosition - ShortPosition;
            if(mirror) difference = -difference;
         
            IMMBuffer[t] = difference;
         }
         else{
            FileReadNumber(handle1);
            FileReadNumber(handle1);
         }
      }
   }
   else{
     Print("File my_data.dat not found, the last error is ", GetLastError());
     return(false);   
   }
   
   FileClose(handle1);
   
   for(i=Bars-2; i>=0; i--){
      
      LongUP[i] = 0;
      LongDOWN[i] = 0;
      ShortUP[i] = 0;
      ShortDOWN[i] = 0;
      
      if(IMMBuffer[i] >= 0){
         if(IMMBuffer[i+1] <= IMMBuffer[i]) LongUP[i] = IMMBuffer[i];
         else LongDOWN[i] = IMMBuffer[i];
      }
      else{
         if(IMMBuffer[i+1] > IMMBuffer[i]) ShortDOWN[i] = IMMBuffer[i];
         else ShortUP[i] = IMMBuffer[i];
      }
   
   }
   
   return(0);
  }
//+------------------------------------------------------------------+


